@@ -22,6 +22,11 @@ class NotificationData:
     scan_session_id: typing.Optional[str] = None
     failed_job_count: typing.Optional[int] = None
     file_attachments: typing.Optional[typing.List[typing.Dict[str, str]]] = None
+    data: typing.Optional[typing.Dict[str, typing.Any]] = None
+    kind: typing.Optional[str] = None
+    address: typing.Optional[str] = None
+    scan_id: typing.Optional[str] = None
+    scanning_app: typing.Optional[str] = None
 
     @classmethod
     def from_dict(cls, data: dict):
